@@ -8,6 +8,7 @@ DATABASES = {
 INSTALLED_APPS = [
     'localflavor',
     'tests.test_br',
+    'tests.test_by',
     'tests.test_au',
     'tests.test_ec',
     'tests.test_md',
@@ -17,9 +18,12 @@ INSTALLED_APPS = [
     'tests.test_us',
     'tests.test_pk',
     'tests.test_cu',
+    'tests.test_gh',
+    'tests.test_np',
+    'tests.test_ca',
     'tests.test_generic',
 ]
 
 SECRET_KEY = 'spam-spam-spam-spam'
 
-SILENCED_SYSTEM_CHECKS = ('1_7.W001',)
+SILENCED_SYSTEM_CHECKS = ('1_7.W001', 'models.W042')
