@@ -122,6 +122,7 @@ class IBANTests(TestCase):
             'GB29ÉWBK60161331926819': 'is not a valid character for IBAN.',
             'SA0380000000608019167519': 'Not a valid IBAN.',
             'EE012200221111099080': 'Not a valid IBAN.',
+            'IT2813815463652787128285355': 'Not a valid IBAN.',
         }
 
         iban_validator = IBANValidator()
@@ -164,9 +165,9 @@ class IBANTests(TestCase):
             'MU17 BOMM 0101 1010 3030 0200 000M UR': 'MU17BOMM0101101030300200000MUR',
             'MU 17BO MM01011010 3030-02 000-00M UR': 'MU17BOMM0101101030300200000MUR',
 
-            'BE68539007547034': 'BE68539007547034',
-            'BE68 5390 0754 7034': 'BE68539007547034',
-            'BE-685390075470 34': 'BE68539007547034',
+            'BE31538007547055': 'BE31538007547055',
+            'BE31 5380 0754 7055': 'BE31538007547055',
+            'BE-315380075470 55': 'BE31538007547055',
         }
 
         invalid = {
@@ -184,8 +185,8 @@ class IBANTests(TestCase):
                 'Ensure this value has at most 34 characters (it has 35).'],
 
             # This IBAN should only be valid only if the Nordea extensions are turned on.
-            'EG1100006001880800100014553': ['EG is not a valid country code for IBAN.'],
-            'EG11 0000 6001 8808 0010 0014 553': ['EG is not a valid country code for IBAN.']
+            'BJ11B00610100400271101192591': ['BJ is not a valid country code for IBAN.'],
+            'BJ11 B006 1010 0400 2711 0119 2591': ['BJ is not a valid country code for IBAN.']
         }
 
         self.assertFieldOutput(IBANFormField, valid=valid, invalid=invalid)
@@ -209,10 +210,10 @@ class IBANTests(TestCase):
         """Test a valid IBAN in the Nordea extensions."""
         iban_validator = IBANValidator(use_nordea_extensions=True)
         # Run the validator to ensure there are no ValidationErrors raised.
-        iban_validator('Eg1100006001880800100014553')
+        iban_validator('Bj11B00610100400271101192591')
 
     def test_use_nordea_extensions_formfield(self):
-        form = UseNordeaExtensionsForm({'iban': 'EG1100006001880800100014553'})
+        form = UseNordeaExtensionsForm({'iban': 'BJ11B00610100400271101192591'})
         self.assertFalse(form.errors)
 
     def test_include_countries_formfield(self):
@@ -233,7 +234,7 @@ class IBANTests(TestCase):
 
         valid = {
             'NL02ABNA0123456789': 'NL02ABNA0123456789',
-            'BE68539007547034': 'BE68539007547034',
+            'BE31538007547055': 'BE31538007547055',
             'LU280019400644750000': 'LU280019400644750000'
         }
 
@@ -322,6 +323,7 @@ class BICTests(TestCase):
             '': 'BIC codes have either 8 or 11 characters.',
             'CIBCJJH2': 'JJ is not a valid country code.',
             'D3UTDEFF': 'is not a valid institution code.',
+            'DAAEDEDOXXX': 'is not a valid location code.',
             'DÉUTDEFF': 'codes only contain alphabet letters and digits.',
             'NEDSZAJJ XX': 'codes only contain alphabet letters and digits.',
         }
