@@ -1,6 +1,6 @@
 from django.db import models
 
-from localflavor.pk.models import PKStateField, PKPostCodeField, PKPhoneNumberField
+from localflavor.pk.models import PKPostCodeField, PKStateField
 
 
 class PakistaniPlace(models.Model):
@@ -10,5 +10,4 @@ class PakistaniPlace(models.Model):
     postcode = PKPostCodeField(blank=True)
     postcode_required = PKPostCodeField()
     postcode_default = PKPostCodeField(default="44000", blank=True)
-    phone = PKPhoneNumberField(blank=True)
     name = models.CharField(max_length=20)
